@@ -16,22 +16,9 @@
 ;    You should have received a copy of the GNU General Public License
 ;    along with TwinLisp; if not, write to the Free Software
 ;    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
-(cl:load "core/PackDef.lisp")
-(tl-set-home-path "" "/")
-(cl:load "core/loadTL.lisp")
-(compile-file "core/PackDef.lisp")
-(compile-file "core/loadTL.lisp")
-(compile-file "core/OtherMacs.lisp")
-(compile-file "core/ContainerTypesAndMacs.lisp")
-(compile-file "core/OperMacs.lisp")
-(compile-file "core/OtherMeths.lisp")
-(compile-file "core/OtherFuncs.lisp")
-(compile-file "core/ContainerMeths.lisp")
-(compile-file "core/OperMeths.lisp")
-(compile-file "core/TranslConst.lisp")
-(compile-file "core/TranslStringReading.lisp")
-(compile-file "core/TranslElemSearchFuncs.lisp")
-(compile-file "core/TranslFormBuilding.lisp")
-(compile-file "core/TranslFormWritting.lisp")
-(compile-file "core/LoaderMacs.lisp")
-(compile-file "core/interpreter.lisp")
+(cl:setf (logical-pathname-translations "tl-sys") (cl:list (cl:list "**;*.*" (concatenate 'string (namestring (ext:cd)) "**/")) (cl:list ";**;*.*" (concatenate 'string (namestring (ext:cd)) "**/"))))
+(cl:load (logical-pathname "tl-sys:core;tl-def"))
+(var comPathList (cl:list "tl-sys:core;other-macs" "tl-sys:core;container-types-and-macs" "tl-sys:core;oper-macs" "tl-sys:core;other-funcs" "tl-sys:core;oper-meths" "tl-sys:core;other-meths" "tl-sys:core;container-meths" ; TL's translator
+ "tl-sys:core;transl-const" "tl-sys:core;transl-string-reading" "tl-sys:core;transl-elem-search-funcs" "tl-sys:core;transl-form-building" "tl-sys:core;transl-form-writting" ; TL's loading func
+ "tl-sys:core;loader-funcs"))
+(tl-for (logPathStr comPathList) (cl:nil) (compile-file (logical-pathname logPathStr)))
